@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Radicale Server - Calendar Server
-# Copyright © 2008-2011 Guillaume Ayoub
+# Copyright © 2008-2012 Guillaume Ayoub
 # Copyright © 2008 Nicolas Kandel
 # Copyright © 2008 Pascal Halter
 #
@@ -39,22 +39,43 @@ except ImportError:
 # Default configuration
 INITIAL_CONFIG = {
     "server": {
-        "host": "",
-        "port": "5232",
+        "hosts": "0.0.0.0:5232",
         "daemon": "False",
+        "pid": "",
         "ssl": "False",
         "certificate": "/etc/apache2/ssl/server.crt",
-        "key": "/etc/apache2/ssl/server.key"},
+        "key": "/etc/apache2/ssl/server.key",
+        "dns_lookup": "True"},
     "encoding": {
         "request": "utf-8",
         "stock": "utf-8"},
     "acl": {
-        "type": "fake",
-        "personal": "False",
-        "filename": "/etc/radicale/users",
-        "encryption": "crypt"},
+        "type": "None",
+        "public_users": "public",
+        "private_users": "private",
+        "htpasswd_filename": "/etc/radicale/users",
+        "htpasswd_encryption": "crypt",
+        "imap_auth_host_name": "localhost",
+        "imap_auth_host_port": "143",
+        "ldap_url": "ldap://localhost:389/",
+        "ldap_base": "ou=users,dc=example,dc=com",
+        "ldap_attribute": "uid",
+        "ldap_filter": "",
+        "ldap_binddn": "",
+        "ldap_password": "",
+        "ldap_scope": "OneLevel",
+        "pam_group_membership": "",
+        "courier_socket": ""},
     "storage": {
-        "folder": os.path.expanduser("~/.config/radicale/calendars")}}
+        "type": "filesystem",
+        "filesystem_folder": os.path.expanduser(
+            "~/.config/radicale/collections"),
+        "git_folder": os.path.expanduser(
+            "~/.config/radicale/collections")},
+    "logging": {
+        "config": "/etc/radicale/logging",
+        "debug": "False",
+        "full_environment": "False"}}
 
 # Create a ConfigParser and configure it
 _CONFIG_PARSER = ConfigParser()
@@ -66,6 +87,8 @@ for section, values in INITIAL_CONFIG.items():
 
 _CONFIG_PARSER.read("/etc/radicale/config")
 _CONFIG_PARSER.read(os.path.expanduser("~/.config/radicale/config"))
+if "RADICALE_CONFIG" in os.environ:
+    _CONFIG_PARSER.read(os.environ["RADICALE_CONFIG"])
 
 # Wrap config module into ConfigParser instance
 sys.modules[__name__] = _CONFIG_PARSER
